@@ -10,7 +10,7 @@ class CommaWidget(atapi.LinesWidget):
         'size' : '30',
         'maxlength' : '255',
         'blurrable' : True,
-        'postback': False, # TODO
+        'show_form_help': True,
         })
 
     def process_form(self, *args, **kw):
