@@ -35,9 +35,21 @@ class FormCriteriaLayer(tcl_ptc.BasePTCLayer):
         self.now = DateTime.DateTime('Jan 15, 2009')
         home.invokeFactory(
             type_name='Document', effectiveDate=self.now-2,
-            id='bar-document-title', title='Bar Document Title')
+            id='bar-document-title', title='Bar Document Title',
+            subject=['bah', 'qux'])
         home.invokeFactory(
             type_name='Event', effectiveDate=self.now,
-            id='baz-event-title', title='Baz Event Title')
+            id='baz-event-title', title='Baz Event Title',
+            # For Events eventType == subject
+            eventType=['qux', 'quux'])
+
+        self.loginAsPortalOwner()
+        self.portal.portal_workflow.doActionFor(
+            home['foo-topic-title'], 'publish')
+        self.portal.portal_workflow.doActionFor(
+            home['bar-document-title'], 'publish')
+        self.portal.portal_workflow.doActionFor(
+            home['baz-event-title'], 'publish')
+        self.login()
 
 formcriteria_layer = FormCriteriaLayer([tcl_ptc.ptc_layer])
